@@ -121,6 +121,8 @@ class AccessKeyFunctionCodeCache(
         lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.LifecycleRule, typing.Dict[builtins.str, typing.Any]]]] = None,
         metrics: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketMetrics, typing.Dict[builtins.str, typing.Any]]]] = None,
         notifications_handler_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+        object_lock_default_retention: typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectLockRetention] = None,
+        object_lock_enabled: typing.Optional[builtins.bool] = None,
         object_ownership: typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectOwnership] = None,
         public_read_access: typing.Optional[builtins.bool] = None,
         removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
@@ -151,13 +153,15 @@ class AccessKeyFunctionCodeCache(
         :param lifecycle_rules: Rules that define how Amazon S3 manages objects during their lifetime. Default: - No lifecycle rules.
         :param metrics: The metrics configuration of this bucket. Default: - No metrics configuration.
         :param notifications_handler_role: The role to be used by the notifications handler. Default: - a new role will be created.
+        :param object_lock_default_retention: The default retention mode and rules for S3 Object Lock. Default retention can be configured after a bucket is created if the bucket already has object lock enabled. Enabling object lock for existing buckets is not supported. Default: no default retention period
+        :param object_lock_enabled: Enable object lock on the bucket. Enabling object lock for existing buckets is not supported. Object lock must be enabled when the bucket is created. Default: false, unless objectLockDefaultRetention is set (then, true)
         :param object_ownership: The objectOwnership of the bucket. Default: - No ObjectOwnership configuration, uploading account will own the object.
         :param public_read_access: Grants public read access to all objects in the bucket. Similar to calling ``bucket.grantPublicAccess()`` Default: false
         :param removal_policy: Policy to apply when the bucket is removed from this stack. Default: - The bucket will be orphaned.
         :param server_access_logs_bucket: Destination bucket for the server access logs. Default: - If "serverAccessLogsPrefix" undefined - access logs disabled, otherwise - log to current bucket.
         :param server_access_logs_prefix: Optional log file prefix to use for the bucket's access logs. If defined without "serverAccessLogsBucket", enables access logs to current bucket with this prefix. Default: - No log file prefix
         :param transfer_acceleration: Whether this bucket should have transfer acceleration turned on or not. Default: false
-        :param versioned: Whether this bucket should have versioning turned on or not. Default: false
+        :param versioned: Whether this bucket should have versioning turned on or not. Default: false (unless object lock is enabled, then true)
         :param website_error_document: The name of the error document (e.g. "404.html") for the website. ``websiteIndexDocument`` must also be set if this is set. Default: - No error document.
         :param website_index_document: The name of the index document (e.g. "index.html") for the website. Enables static website hosting for this bucket. Default: - No index document.
         :param website_redirect: Specifies the redirect behavior of all requests to a website endpoint of a bucket. If you specify this property, you can't specify "websiteIndexDocument", "websiteErrorDocument" nor , "websiteRoutingRules". Default: - No redirection.
@@ -183,6 +187,8 @@ class AccessKeyFunctionCodeCache(
             lifecycle_rules=lifecycle_rules,
             metrics=metrics,
             notifications_handler_role=notifications_handler_role,
+            object_lock_default_retention=object_lock_default_retention,
+            object_lock_enabled=object_lock_enabled,
             object_ownership=object_ownership,
             public_read_access=public_read_access,
             removal_policy=removal_policy,
@@ -269,6 +275,8 @@ class AccessKeyFunctionCodeCache(
         "lifecycle_rules": "lifecycleRules",
         "metrics": "metrics",
         "notifications_handler_role": "notificationsHandlerRole",
+        "object_lock_default_retention": "objectLockDefaultRetention",
+        "object_lock_enabled": "objectLockEnabled",
         "object_ownership": "objectOwnership",
         "public_read_access": "publicReadAccess",
         "removal_policy": "removalPolicy",
@@ -301,6 +309,8 @@ class AccessKeyFunctionCodeCacheProps(_aws_cdk_aws_s3_ceddda9d.BucketProps):
         lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.LifecycleRule, typing.Dict[builtins.str, typing.Any]]]] = None,
         metrics: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketMetrics, typing.Dict[builtins.str, typing.Any]]]] = None,
         notifications_handler_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+        object_lock_default_retention: typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectLockRetention] = None,
+        object_lock_enabled: typing.Optional[builtins.bool] = None,
         object_ownership: typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectOwnership] = None,
         public_read_access: typing.Optional[builtins.bool] = None,
         removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
@@ -329,13 +339,15 @@ class AccessKeyFunctionCodeCacheProps(_aws_cdk_aws_s3_ceddda9d.BucketProps):
         :param lifecycle_rules: Rules that define how Amazon S3 manages objects during their lifetime. Default: - No lifecycle rules.
         :param metrics: The metrics configuration of this bucket. Default: - No metrics configuration.
         :param notifications_handler_role: The role to be used by the notifications handler. Default: - a new role will be created.
+        :param object_lock_default_retention: The default retention mode and rules for S3 Object Lock. Default retention can be configured after a bucket is created if the bucket already has object lock enabled. Enabling object lock for existing buckets is not supported. Default: no default retention period
+        :param object_lock_enabled: Enable object lock on the bucket. Enabling object lock for existing buckets is not supported. Object lock must be enabled when the bucket is created. Default: false, unless objectLockDefaultRetention is set (then, true)
         :param object_ownership: The objectOwnership of the bucket. Default: - No ObjectOwnership configuration, uploading account will own the object.
         :param public_read_access: Grants public read access to all objects in the bucket. Similar to calling ``bucket.grantPublicAccess()`` Default: false
         :param removal_policy: Policy to apply when the bucket is removed from this stack. Default: - The bucket will be orphaned.
         :param server_access_logs_bucket: Destination bucket for the server access logs. Default: - If "serverAccessLogsPrefix" undefined - access logs disabled, otherwise - log to current bucket.
         :param server_access_logs_prefix: Optional log file prefix to use for the bucket's access logs. If defined without "serverAccessLogsBucket", enables access logs to current bucket with this prefix. Default: - No log file prefix
         :param transfer_acceleration: Whether this bucket should have transfer acceleration turned on or not. Default: false
-        :param versioned: Whether this bucket should have versioning turned on or not. Default: false
+        :param versioned: Whether this bucket should have versioning turned on or not. Default: false (unless object lock is enabled, then true)
         :param website_error_document: The name of the error document (e.g. "404.html") for the website. ``websiteIndexDocument`` must also be set if this is set. Default: - No error document.
         :param website_index_document: The name of the index document (e.g. "index.html") for the website. Enables static website hosting for this bucket. Default: - No index document.
         :param website_redirect: Specifies the redirect behavior of all requests to a website endpoint of a bucket. If you specify this property, you can't specify "websiteIndexDocument", "websiteErrorDocument" nor , "websiteRoutingRules". Default: - No redirection.
@@ -360,6 +372,8 @@ class AccessKeyFunctionCodeCacheProps(_aws_cdk_aws_s3_ceddda9d.BucketProps):
             check_type(argname="argument lifecycle_rules", value=lifecycle_rules, expected_type=type_hints["lifecycle_rules"])
             check_type(argname="argument metrics", value=metrics, expected_type=type_hints["metrics"])
             check_type(argname="argument notifications_handler_role", value=notifications_handler_role, expected_type=type_hints["notifications_handler_role"])
+            check_type(argname="argument object_lock_default_retention", value=object_lock_default_retention, expected_type=type_hints["object_lock_default_retention"])
+            check_type(argname="argument object_lock_enabled", value=object_lock_enabled, expected_type=type_hints["object_lock_enabled"])
             check_type(argname="argument object_ownership", value=object_ownership, expected_type=type_hints["object_ownership"])
             check_type(argname="argument public_read_access", value=public_read_access, expected_type=type_hints["public_read_access"])
             check_type(argname="argument removal_policy", value=removal_policy, expected_type=type_hints["removal_policy"])
@@ -402,6 +416,10 @@ class AccessKeyFunctionCodeCacheProps(_aws_cdk_aws_s3_ceddda9d.BucketProps):
             self._values["metrics"] = metrics
         if notifications_handler_role is not None:
             self._values["notifications_handler_role"] = notifications_handler_role
+        if object_lock_default_retention is not None:
+            self._values["object_lock_default_retention"] = object_lock_default_retention
+        if object_lock_enabled is not None:
+            self._values["object_lock_enabled"] = object_lock_enabled
         if object_ownership is not None:
             self._values["object_ownership"] = object_ownership
         if public_read_access is not None:
@@ -613,6 +631,36 @@ class AccessKeyFunctionCodeCacheProps(_aws_cdk_aws_s3_ceddda9d.BucketProps):
         result = self._values.get("notifications_handler_role")
         return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole], result)
 
+    @builtins.property
+    def object_lock_default_retention(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectLockRetention]:
+        '''The default retention mode and rules for S3 Object Lock.
+
+        Default retention can be configured after a bucket is created if the bucket already
+        has object lock enabled. Enabling object lock for existing buckets is not supported.
+
+        :default: no default retention period
+
+        :see: https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-lock-overview.html#object-lock-bucket-config-enable
+        '''
+        result = self._values.get("object_lock_default_retention")
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectLockRetention], result)
+
+    @builtins.property
+    def object_lock_enabled(self) -> typing.Optional[builtins.bool]:
+        '''Enable object lock on the bucket.
+
+        Enabling object lock for existing buckets is not supported. Object lock must be
+        enabled when the bucket is created.
+
+        :default: false, unless objectLockDefaultRetention is set (then, true)
+
+        :see: https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-lock-overview.html#object-lock-bucket-config-enable
+        '''
+        result = self._values.get("object_lock_enabled")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def object_ownership(
         self,
@@ -681,7 +729,7 @@ class AccessKeyFunctionCodeCacheProps(_aws_cdk_aws_s3_ceddda9d.BucketProps):
     def versioned(self) -> typing.Optional[builtins.bool]:
         '''Whether this bucket should have versioning turned on or not.
 
-        :default: false
+        :default: false (unless object lock is enabled, then true)
         '''
         result = self._values.get("versioned")
         return typing.cast(typing.Optional[builtins.bool], result)
@@ -900,6 +948,8 @@ def _typecheckingstub__32c12ba2ba385b059d2f5a99ddbf7658a712a38310111970807a466f3
     lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.LifecycleRule, typing.Dict[builtins.str, typing.Any]]]] = None,
     metrics: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketMetrics, typing.Dict[builtins.str, typing.Any]]]] = None,
     notifications_handler_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    object_lock_default_retention: typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectLockRetention] = None,
+    object_lock_enabled: typing.Optional[builtins.bool] = None,
     object_ownership: typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectOwnership] = None,
     public_read_access: typing.Optional[builtins.bool] = None,
     removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
@@ -951,6 +1001,8 @@ def _typecheckingstub__7e41c3f9874c8b25a41a2f7c64041fe0d2589a77dcc8f555585ff7cbc
     lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.LifecycleRule, typing.Dict[builtins.str, typing.Any]]]] = None,
     metrics: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketMetrics, typing.Dict[builtins.str, typing.Any]]]] = None,
     notifications_handler_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    object_lock_default_retention: typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectLockRetention] = None,
+    object_lock_enabled: typing.Optional[builtins.bool] = None,
     object_ownership: typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectOwnership] = None,
     public_read_access: typing.Optional[builtins.bool] = None,
     removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
